<?php

namespace Drupal\aegir_site_subscriptions\HostingServiceCalls;

use Drupal\node\NodeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class for verifying sites via Aegir's Web service API.
 */
class SiteVerifyHostingServiceCall extends SiteHostingServiceCall {
  use TaskCreationTrait;

  /**
   * The remote site task being executed by this hosting service call.
   */
  const TASK_TYPE = 'verify';

  /**
   * The activity that was performed by this service call's execution.
   */
  const ACTION_PERFORMED = 'Site verified';

  /**
   * {@inheritdoc}
   *
   * @param \Drupal\node\NodeInterface $site
   *   The site to act upon.
   *
   * @return \Drupal\aegir_site_subscriptions\HostingServiceCalls\SiteVerifyHostingServiceCall
   *
   * @throws \Exception
   */
  public static function create(ContainerInterface $container, NodeInterface$site) {
    return new static(
      $container->get('logger.factory')->get('aegir_site_subscriptions'),
      $container->get('http_client'),
      $container->get('config.factory')->get('aegir_site_subscriptions.settings'),
      $container->get('request_stack')->getCurrentRequest(),
      $container->get('module_handler'),
      $container->get('messenger'),
      $site
    );
  }

  /**
   * {@inheritdoc}
   *
   * Verifies a site.
   */
  protected function execute() {
    $this->sendRequestAndReceiveResponse('task', [
      'type' => $this->getTaskType(),
      'target' => $this->getSiteName(),
    ]);

    return $this;
  }

  /**
   * {@inheritdoc}
   *
   * @throws \ReflectionException
   */
  protected function recordSuccessLogMessage() {
    $this->logger
      ->info('Remote site %sitename: Task %task created to verify it via %fetcher.', [
        '%sitename' => $this->getSiteName(),
        '%task' => $this->getTaskId(),
        '%fetcher' => $this->getClassName(),
      ]);
    return $this;
  }

}
