<?php

namespace Drupal\aegir_site_subscriptions\Wrappers;

use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Base class for externally managed objects.
 */
abstract class Wrapper {

  /**
   * The current HTTP/S request.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $currentRequest;

  /**
   * Node storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * This module's configuration.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $moduleConfig;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * The logging service.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The user messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $userMessenger;

  /**
   * Class Constructor.
   *
   * @param \Symfony\Component\HttpFoundation\Request $current_request
   *   The current HTTP/S request.
   * @param \Drupal\Core\Entity\EntityStorageInterface $node_storage
   *   Node storage.
   * @param \Drupal\Core\Config\ImmutableConfig $module_config
   *   This module's configuration.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   * @param \Psr\Log\LoggerInterface $logger
   *   The logging service.
   * @param \Drupal\Core\Messenger\MessengerInterface $user_messenger
   *   The module handler.
   */
  public function __construct(
      Request $current_request = NULL,
      EntityStorageInterface $node_storage = NULL,
      ImmutableConfig $module_config = NULL,
      ModuleHandlerInterface $module_handler = NULL,
      LoggerInterface $logger = NULL,
      MessengerInterface $user_messenger = NULL
  ) {
    $service_container = \Drupal::getContainer();

    $this->currentRequest = $current_request ?: $service_container->get('request_stack')->getCurrentRequest();
    $this->nodeStorage = $node_storage ?: $service_container->get('entity_type.manager')->getStorage('node');
    $this->moduleConfig = $module_config ?: $service_container->get('config.factory')->get('aegir_site_subscriptions.settings');
    $this->moduleHandler = $module_handler ?: $service_container->get('module_handler');
    $this->logger = $logger ?: $service_container->get('logger.factory')->get('aegir_site_subscriptions');
    $this->userMessenger = $user_messenger ?: $service_container->get('messenger');
  }

}
